Coverage for tictactoe/contest/migrations/0001_initial: 100%

# Coverage for tictactoe/contest/migrations/0001_initial : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 | # encoding: utf8 from django.db import models, migrations from django.conf import settings import tictactoe.tools.validators class Migration(migrations.Migration): dependencies = [ migrations.swappable_dependency(settings.AUTH_USER_MODEL), ] operations = [ migrations.CreateModel( name='Entry', fields=[ ('id', models.AutoField(primary_key=True, verbose_name='ID', serialize=False, auto_created=True)), ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL, to_field='id')), ('code', models.TextField(validators=[tictactoe.tools.validators.ByteLengthValidator(60000)])), ('uploaded', models.DateTimeField(auto_now_add=True)), ('modified', models.DateTimeField(auto_now=True)), ], options={ }, bases=(models.Model,), ), ]